==> order-center-api-2.9.0-CLOUD-20240202.024418-11-sources.jar: com/tydic/dyc/oc/service/cmporder/bo/UocGetCmpOrderDetailServiceRspItemMapBo.java <==
package com.tydic.dyc.oc.service.cmporder.bo;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 标题：类名称:UocGetCmpOrderDetailServiceReqItemBo
 * 说明：描述一下类的作用TODO
 * 时间：2022/3/29 14:06
 * 作者 @author 尹栋梁
 */
@Data
public class UocGetCmpOrderDetailServiceRspItemMapBo implements Serializable {

    private static final long serialVersionUID = -5212505623321632322L;
    @DocField(value = "id")
    private Long id;

    @DocField(value = "比选单明细id")
    private Long cmpOrderItemId;

    @DocField(value = "订单id")
    private Long orderId;

    @DocField(value = "字段编码")
    private String fieldCode;

    @DocField(value = "字段名称")
    private String fieldName;

    @DocField(value = "字段值")
    private String fieldValue;

    @DocField(value = "删除标志1已删除")
    private Integer delTag;

    @DocField(value = "创建时间")
    private Date createTime;

    @DocField(value = "创建时间 开始")
    private Date createTimeStart;

    @DocField(value = "创建时间 结束")
    private Date createTimeEnd;

    @DocField(value = "创建工号")
    private String createOperId;

    @DocField(value = "更新时间")
    private Date updateTime;

    @DocField(value = "更新时间 开始")
    private Date updateTimeStart;

    @DocField(value = "更新时间 结束")
    private Date updateTimeEnd;

    @DocField(value = "更新工号")
    private String updateOperId;

    @DocField(value = "备注")
    private String remark;

    @DocField(value = "排序")
    private String orderBy;

}

==> order-center-api-3.0.0-CLOUD-20251111.094209-89-sources.jar: com/tydic/dyc/oc/service/cmporder/bo/UocGetCmpOrderDetailServiceRspItemMapBo.java <==
package com.tydic.dyc.oc.service.cmporder.bo;

import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * 标题：类名称:UocGetCmpOrderDetailServiceReqItemBo
 * 说明：描述一下类的作用TODO
 * 时间：2022/3/29 14:06
 * 作者 @author 尹栋梁
 */
@Data
public class UocGetCmpOrderDetailServiceRspItemMapBo implements Serializable {

    private static final long serialVersionUID = -5212505623321632322L;
    /**
     * id
     */
    private Long id;

    /**
     * 比选单明细id
     */
    private Long cmpOrderItemId;

    /**
     * 订单id
     */
    private Long orderId;

    /**
     * 字段编码
     */
    private String fieldCode;

    /**
     * 字段名称
     */
    private String fieldName;

    /**
     * 字段值
     */
    private String fieldValue;

    /**
     * 删除标志1已删除
     */
    private Integer delTag;

    /**
     * 创建时间
     */
    private Date createTime;

    /**
     * 创建时间 开始
     */
    private Date createTimeStart;

    /**
     * 创建时间 结束
     */
    private Date createTimeEnd;

    /**
     * 创建工号
     */
    private String createOperId;

    /**
     * 更新时间
     */
    private Date updateTime;

    /**
     * 更新时间 开始
     */
    private Date updateTimeStart;

    /**
     * 更新时间 结束
     */
    private Date updateTimeEnd;

    /**
     * 更新工号
     */
    private String updateOperId;

    /**
     * 备注
     */
    private String remark;

    /**
     * 排序
     */
    private String orderBy;
    /**
     * 租户id
     */
    private Long sysTenantId;
    private String sysTenantName;
}
